@@ -309,6 +309,12 @@ public class Project implements ResourceFactory {
         setAntLib();
     }
 
+    /**
+     * Set a property to the location of ant.jar.
+     * Use the locator to find the location of the Project.class, and
+     * if this is not null, set the property {@link MagicNames#ANT_LIB}
+     * to the result
+     */
     private void setAntLib() {
         File antlib = org.apache.tools.ant.launch.Locator.getClassSource(
             Project.class);
@@ -910,7 +916,9 @@ public class Project implements ResourceFactory {
         while (e.hasMoreElements()) {
             String propertyName = (String) e.nextElement();
             String value = systemP.getProperty(propertyName);
-            this.setPropertyInternal(propertyName, value);
+            if (value != null) {
+                this.setPropertyInternal(propertyName, value);
+            }
         }
     }
 
@@ -1651,6 +1659,27 @@ public class Project implements ResourceFactory {
                 || "yes".equalsIgnoreCase(s));
     }
 
+    /**
+     * Get the Project instance associated with the specified object.
+     * @param o the object to query.
+     * @return Project instance, if any.
+     * @since Ant 1.7.1
+     */
+    public static Project getProject(Object o) {
+        if (o instanceof ProjectComponent) {
+            return ((ProjectComponent) o).getProject();
+        }
+        try {
+            Method m = o.getClass().getMethod("getProject", (Class[]) null);
+            if (Project.class == m.getReturnType()) {
+                return (Project) m.invoke(o, (Object[]) null);
+            }
+        } catch (Exception e) {
+            //too bad
+        }
+        return null;
+    }
+
     /**
      * Topologically sort a set of targets.  Equivalent to calling
      * <code>topoSort(new String[] {root}, targets, true)</code>.
